//Author: Oliver-Matis Lill
//Full solution to task disko.
//This solution groups the span endpoints into connected
//components (by switch segments). In each connected component
//it's possible to switch any segment specified by any two
//endpoints in the component.
//Then it finds a cycle cover on graph where the connected
//componets are vertices, the initial "on segments" are edges
//and where each edge is covered.
//If no such cover exists, then there is no solution.
//Time complexity: O(N+M)
#include<iostream>
#include<vector>
#include<fstream>
#include<algorithm>
#define f first
#define s second
#define mp make_pair
#define MAX_NODES 400000
using namespace std;


struct Edge{
	int next, index;
	Edge(int newNext = 0, int newIndex = 0) {
		next = newNext, index = newIndex;
	}
};


//--------------------------------------------------------
//Forest structure

struct Forest{
	//Large scope variables and functions
	vector<Edge> edge[MAX_NODES];
	
	void addEdge(int a, int b, int index) {
		edge[a].push_back(Edge(b, index));
		edge[b].push_back(Edge(a, index));
	}
	
	

	//------------------------------------------------------
	//Forest functionality for toggling switch spans
	
	//vector<Edge> edge[MAX_NODES]
	int master[MAX_NODES];
	int parent[MAX_NODES][20];
	int toSwitch[MAX_NODES];
	
	void forestInitDFS(int pos, int root, vector<bool> &explr) {
		if(explr[pos])
			return;
		explr[pos] = true;
		master[pos] = root;
		
		//Recursion
		for(auto e : edge[pos])
			forestInitDFS(e.next, root, explr);
	}
	
	//Forest Initialization Front-End
	void forestInit() {
		vector<bool> explr(MAX_NODES, false);
		for(int i=0;i<MAX_NODES;i++)
			forestInitDFS(i, i, explr), toSwitch[i] = 0;
	}
	
	
	//-----------------------------------------------------------------------------
	//Finally functionality to allow switching segments
	
	//int depth[MAX_NODES], toSwitch[MAX_NODES], parentEdgeIndex[MAX_NODES];
	int shouldSwitch[100000];
	
	void switchSegment(int a, int b) {
		
		toSwitch[a]++;
		toSwitch[b]++;
	}
	
	//Finally calculate what edges should be switched
	int getSwitchDFS(int pos, int parentEdgeIndex, vector<bool>& explr) {
		if(explr[pos])
			return 0;
		explr[pos] = true;
		
		int subSum = toSwitch[pos];
		for(auto e : edge[pos])
			subSum += getSwitchDFS(e.next, e.index, explr);
		
		subSum %= 2;
		if(parentEdgeIndex != -1)
			shouldSwitch[parentEdgeIndex] = subSum;
			
		return subSum;
	}
	
	void getSwitch() {
		vector<bool> explr(MAX_NODES, false);
		
		for(int i=0;i<MAX_NODES;i++)
			getSwitchDFS(i, -1, explr);
	}
	
	
}forest;





//--------------------------------------------------------
//Graph structure for Euler's algorithm

struct GraphEdge : public Edge {
	int source;
	bool used;
	size_t counterpartIndex;
	
	GraphEdge(int newSource = 0, int newNext = 0, int newIndex = 0) : Edge(newNext, newIndex) {
		source = newSource;
		used = false;
	}
};




struct Graph {
	vector<GraphEdge> edge[MAX_NODES];
	int degree[MAX_NODES];
	
	void addEdge(int a, int b, int index) {
		int ma = forest.master[a];
		int mb = forest.master[b];
		
		size_t fromA, fromB;
		
		fromA = edge[ma].size();
		edge[ma].push_back(GraphEdge(a, b, index) );
		
		fromB = edge[mb].size();
		edge[mb].push_back(GraphEdge(b, a, index) );
		
		edge[ma][fromA].counterpartIndex = fromB;
		edge[mb][fromB].counterpartIndex = fromA;
		
		degree[ma]++;
		degree[mb]++;
	}
	
	
	//Check validity
	bool valid() {
		for(int i=0;i<MAX_NODES;i++)
			if(degree[i]%2 == 1)
				return false;
		return true;
	}
	
	
	//----------------------------------
	//Find a cycle
	
	void getCycle(int startPosition, vector<size_t> &ind) {
		
		vector<int> pos(1, startPosition);
		
		while(pos.size() > 0) {
			int cm = pos.back();
			
			while(ind[cm] < edge[cm].size() && edge[cm][ind[cm]].used)
				ind[cm]++;
			
			//Add the endpoint of edge
			if(ind[cm] < edge[cm].size() ) {
				auto &curEdge = edge[cm][ind[cm]];
				curEdge.used = true;
				
				int nm = forest.master[curEdge.next];
				forest.switchSegment(cm, curEdge.source);
				forest.switchSegment(curEdge.next, nm);
				
				edge[nm][curEdge.counterpartIndex].used = true;
				pos.push_back(nm);
			}
			else {
				pos.pop_back();
			}
			
		}
		
	}
	
	
	
	void solve() {
		vector<size_t> ind(MAX_NODES, 0);
		
		for(int i=0;i<MAX_NODES;i++)
			if(forest.master[i] == i)
				getCycle(i, ind);
	}
	
}graph;






//---------------------------------------------------------------
//Main function here

int n, m, p1, p2;
vector<pair<int, int> > iniseg, switchseg;
vector<int> pts;



int main() {
	ifstream in("diskosis.txt");
	in >> n >> n;
	
	for(int i=0;i<n;i++) {
		in >> p1 >> p2;
		p2++;
		iniseg.push_back(mp(p1, p2) );
		pts.push_back(p1);
		pts.push_back(p2);
	}
	
	in >> m;
	
	for(int i=0;i<m;i++) {
		in >> p1 >> p2;
		p2++;
		switchseg.push_back(mp(p1, p2) );
		pts.push_back(p1);
		pts.push_back(p2);
	}
	
	sort(pts.begin(), pts.end() );
	pts.resize(unique(pts.begin(), pts.end() ) - pts.begin() );
	
	
	//----------------------------------------------------
	//Next add edges to forest
	
	int ind = 0;
	for(auto cur : switchseg) {
		int a = lower_bound(pts.begin(), pts.end(), cur.f) - pts.begin();
		int b = lower_bound(pts.begin(), pts.end(), cur.s) - pts.begin();
		
		forest.addEdge(a, b, ind++);
	}
	
	forest.forestInit();
	
	
	
	//Finally see if inital segments can be switched off
	ind = 0;
	for(auto cur : iniseg) {
		int a = lower_bound(pts.begin(), pts.end(), cur.f) - pts.begin();
		int b = lower_bound(pts.begin(), pts.end(), cur.s) - pts.begin();
		
		graph.addEdge(a, b, ind++);
	}
	
	//Now output the result
	ofstream out("diskoval.txt");
	
	if(!graph.valid() ) {
		out << "EI\n";
		return 0;
	}
	
	
	graph.solve();
	forest.getSwitch();
	
	out << "JAH\n";
	for(int i=0;i<m;i++)
		out << forest.shouldSwitch[i] << ' ';
	out << '\n';
	
	
	return 0;
}









































